pub enum Attribute {
Opaque,
Exclude,
Rename(String),
VariantsPrefix(String),
VariantsSuffix(String),
Transparent,
IsContract {
kind: String,
target: MaybeAssocItemId,
},
HasContract {
kind: String,
contract: FunDeclId,
},
DocComment(String),
Builtin(AttributeKind),
Unknown(RawAttribute),
}Expand description
Attributes (#[...]).
Variants
Opaque
Do not translate the body of this item.
Written #[charon::opaque]
Exclude
Do not translate this item at all.
Written #[charon::exclude]
Rename(String)
Provide a new name that consumers of the llbc can use.
Written #[charon::rename("new_name")]
VariantsPrefix(String)
For enums only: rename the variants by pre-pending their names with the given prefix.
Written #[charon::variants_prefix("prefix_")].
VariantsSuffix(String)
Same as VariantsPrefix, but appends to the name instead of pre-pending.
Transparent
The structure is treated as a transparent wrapper around its sole field.
Written #[charon::transparent].
IsContract
An item annotated with #[charon::contract(kind = "...", parent)] or
#[charon::contract(kind = "...", for = "...")]. This makes it a contract for the target
item.
HasContract
An item that has a contract that applies to it. The referenced item is the function that specifies the contract.
DocComment(String)
A doc-comment such as /// ....
Builtin(AttributeKind)
A built-in attribute.
Unknown(RawAttribute)
None of the above.
Implementations
Sourceimpl Attribute
impl Attribute
pub fn is_opaque(&self) -> bool
pub fn is_exclude(&self) -> bool
pub fn is_rename(&self) -> bool
pub fn is_variants_prefix(&self) -> bool
pub fn is_variants_suffix(&self) -> bool
pub fn is_transparent(&self) -> bool
pub fn is_is_contract(&self) -> bool
pub fn is_has_contract(&self) -> bool
pub fn is_doc_comment(&self) -> bool
pub fn is_builtin(&self) -> bool
pub fn is_unknown(&self) -> bool
Sourceimpl Attribute
impl Attribute
pub fn as_opaque(&self) -> Option<()>
pub fn as_exclude(&self) -> Option<()>
pub fn as_rename(&self) -> Option<&String>
pub fn as_variants_prefix(&self) -> Option<&String>
pub fn as_variants_suffix(&self) -> Option<&String>
pub fn as_transparent(&self) -> Option<()>
pub fn as_is_contract(&self) -> Option<(&String, &MaybeAssocItemId)>
pub fn as_has_contract(&self) -> Option<(&String, &FunDeclId)>
pub fn as_doc_comment(&self) -> Option<&String>
pub fn as_builtin(&self) -> Option<&AttributeKind>
pub fn as_unknown(&self) -> Option<&RawAttribute>
Sourceimpl Attribute
impl Attribute
pub fn as_opaque_mut(&mut self) -> Option<()>
pub fn as_exclude_mut(&mut self) -> Option<()>
pub fn as_rename_mut(&mut self) -> Option<&mut String>
pub fn as_variants_prefix_mut(&mut self) -> Option<&mut String>
pub fn as_variants_suffix_mut(&mut self) -> Option<&mut String>
pub fn as_transparent_mut(&mut self) -> Option<()>
pub fn as_is_contract_mut( &mut self, ) -> Option<(&mut String, &mut MaybeAssocItemId)>
pub fn as_has_contract_mut(&mut self) -> Option<(&mut String, &mut FunDeclId)>
pub fn as_doc_comment_mut(&mut self) -> Option<&mut String>
pub fn as_builtin_mut(&mut self) -> Option<&mut AttributeKind>
pub fn as_unknown_mut(&mut self) -> Option<&mut RawAttribute>
Sourceimpl Attribute
impl Attribute
pub fn to_opaque(self) -> Option<()>
pub fn to_exclude(self) -> Option<()>
pub fn to_rename(self) -> Option<String>
pub fn to_variants_prefix(self) -> Option<String>
pub fn to_variants_suffix(self) -> Option<String>
pub fn to_transparent(self) -> Option<()>
pub fn to_is_contract(self) -> Option<(String, MaybeAssocItemId)>
pub fn to_has_contract(self) -> Option<(String, FunDeclId)>
pub fn to_doc_comment(self) -> Option<String>
pub fn to_builtin(self) -> Option<AttributeKind>
pub fn to_unknown(self) -> Option<RawAttribute>
Sourceimpl Attribute
impl Attribute
fn fmt_unindented<C: AstFormatter>(&self, ctx: &C, f: &mut impl Write) -> Result